@@ -1,5 +1,5 @@
 package App::GitGot::Repo::Git;
-$App::GitGot::Repo::Git::VERSION = '1.12';
+$App::GitGot::Repo::Git::VERSION = '1.13';
 # ABSTRACT: Git repo objects
 use Mouse;
 extends 'App::GitGot::Repo';
@@ -41,8 +41,8 @@ sub _build__wrapper {
                              remote symbolic_ref / ) {
       $mock->mock( $method => sub { return( '1' )});
     }
-    $mock->mock( 'status' => sub { package MyFake;
-$MyFake::VERSION = '1.12'; sub get { return () }; return bless {} , 'MyFake' } );
+    $mock->mock( 'status' => sub { package
+                                     MyFake; sub get { return () }; return bless {} , 'MyFake' } );
     $mock->mock( 'config' => sub { 0 });
     $mock->mock( 'ERR'    => sub { [ ] });
 
@@ -105,7 +105,7 @@ App::GitGot::Repo::Git - Git repo objects
 
 =head1 VERSION
 
-version 1.12
+version 1.13
 
 =head1 METHODS
 
